ScopedName

Struct ScopedName 

#[repr(C)]
pub struct ScopedName<Name = String> { pub scope: Name, pub name: Name, }
Name in the format <owner>/<drop>.

Fields

scope: Name

The namespace of the drop.

name: Name

The drop’s given name.

Implementations

Source

impl<N> ScopedName<N>

pub fn new<A, B>(scope: A, name: B) -> Self
where A: Into<N>, B: Into<N>,

Creates a new instance from scope and name.

pub fn parse<A, NE>(name: A) -> Result<Self, ParseError<NE>>
where A: TryInto<Self, Error = ParseError<NE>>,

Attempts to create a new instance by parsing name.

pub fn cast<A>(self) -> ScopedName<A>
where N: Into<A>,

Converts self into a new ScopedName by performing an Into conversion over all fields.

pub fn try_cast<A>(self) -> Result<ScopedName<A>, ParseError<N::Error>>
where N: TryInto<A>,

Converts self into a new Query by performing an Into conversion over all fields.

pub fn as_ref(&self) -> ScopedName<&N>

Takes shared references to the fields of this name.

pub fn to_ref<A>(&self) -> ScopedName<&A>
where N: AsRef<A>, A: ?Sized,

Takes a shared reference to the fields of this name as type A.

pub fn as_mut(&mut self) -> ScopedName<&mut N>

Takes mutable references to the fields of this name.

pub fn to_mut<A>(&mut self) -> ScopedName<&mut A>
where N: AsMut<A>, A: ?Sized,

Takes a mutable references to the fields of this name as type A.

pub fn map<A, F>(self, f: F) -> ScopedName<A>
where F: FnMut(N) -> A,

Creates a new ScopedName by mapping the function over the fields of self.

pub fn into_query(self) -> Query<N>

Converts self into a Query.

pub fn into_query_with<V>(self, version: V) -> Query<N, V>

Converts self into a Query with the specified version.

pub fn as_names_array(&self) -> &[N; 2]

Converts self into an array of names.

pub fn as_names_slice(&self) -> &[N]

Converts self into a slice of names.

Source

impl<'n, N: ?Sized> ScopedName<&'n N>

pub fn cloned(&self) -> ScopedName<N>
where N: Clone,

Returns the result of calling Clone::clone on the fields of self.

pub fn to_owned(&self) -> ScopedName<N::Owned>
where N: ToOwned,

Returns the result of calling ToOwned::to_owned on the fields of self.

Examples
use oceanpkg::drop::name::ScopedName;

let name:  ScopedName<&str>   = ScopedName::new("core", "wget");
let owned: ScopedName<String> = name.to_owned();

assert_eq!(name, owned);
Source

impl<'n> ScopedName<&'n Name>

pub const fn core(name: &'n Name) -> Self

Creates a new instance in the core namespace.

pub const fn ocean(name: &'n Name) -> Self

Creates a new instance in the ocean namespace.

pub fn from_pair<S, N>( scope: &'n S, name: &'n N, ) -> Result<Self, ParseError<ValidateError>>
where S: ?Sized + AsRef<[u8]>, N: ?Sized + AsRef<[u8]>,

Creates a new instance by verifying scope and name.

pub unsafe fn from_pair_unchecked<S, N>(scope: &'n S, name: &'n N) -> Self
where S: ?Sized + AsRef<[u8]>, N: ?Sized + AsRef<[u8]>,

Creates a new instance without attempting to verify scope or name.