Struct Source 

pub struct Source { /* private fields */ }
The source of a drop.

Implementations

Source

impl Source

pub fn main_registry() -> &'static Self

A drop source for the main Ocean registry.

pub const fn from_registry(url: Url) -> Self

A drop source at a Url for an Ocean registry.

pub fn from_git(url: Url) -> Self

A drop source at a Url for to a git repository.

pub const fn from_git_at(url: Url, reference: Ref) -> Self

A drop source at a Url for a git repository at a specific reference.

pub const fn url(&self) -> &Url

Where this source is located.

pub const fn kind(&self) -> &Kind

The type of source.